from ... import qs_config, requirePackage

_chatbot = None


def ChatGPT(prompt: str, system_prompt: str = None, record_history=True):
    global _chatbot

    if not _chatbot:
        _config = qs_config.basicSelect("gpt")
        api_supporter = _config["index"]
        model = _config["model"]
        _chatbot = requirePackage(".API.GPT." + api_supporter, "create_bot")(
            model,
            system_prompt=(
                qs_config.basicSelect("gpt")["prompt"]
                if not system_prompt
                else system_prompt
            ),
            record_history=record_history,
        )

    return _chatbot.ask_stream(prompt)



from .GPT import ChatGPT
from .. import user_lang

def translate(text, target_lang=user_lang.lower()):
    prompt = f"Please translate into {target_lang} (avoid explaining the original text): {text}"
    response = ChatGPT(prompt, system_prompt="You are a professional, authentic translation engine. You only return the translated text, without any explanations.", record_history=False)
    return response
